@@ -1,7 +1,9 @@
 """A Python wrapper around the Avanza mobile API."""
 import json
 import logging
-import urllib
+import urllib.error
+import urllib.request
+from typing import Any, Dict
 
 import aiohttp
 
@@ -10,12 +12,12 @@ AVANZA_API_BASE_URL = "https://www.avanza.se/_mobile/market"
 AVANZA_API_STOCK_URL = AVANZA_API_BASE_URL + "/stock/{id}"
 
 
-def get_stock(id: int) -> dict:
+def get_stock(id: int) -> Dict[str, Any]:
     """Get latest information of a stock."""
     url = AVANZA_API_STOCK_URL.format(id=id)
     try:
         resp = urllib.request.urlopen(url).read()
-        return json.loads(resp.decode())
+        return json.loads(resp.decode())  # type: ignore
     except urllib.error.HTTPError as e:
         LOGGER.warning("HTTP Error %d: %s" % (e.code, e.reason))
     except urllib.error.URLError as e:
@@ -23,14 +25,14 @@ def get_stock(id: int) -> dict:
     return {}
 
 
-async def get_stock_async(session: aiohttp.ClientSession, id: int) -> dict:
+async def get_stock_async(session: aiohttp.ClientSession, id: int) -> Dict[str, Any]:
     """Get latest information of a stock asynchronously."""
     url = AVANZA_API_STOCK_URL.format(id=id)
     try:
         resp = await session.get(url, raise_for_status=True)
-        return await resp.json()
+        return await resp.json()  # type: ignore
     except aiohttp.ClientResponseError as e:
-        LOGGER.warning("HTTP Error %d: %s" % (e.status, e.message))
+        LOGGER.warning("Response Error %d: %s" % (e.status, e.message))
     except aiohttp.ClientConnectionError as e:
-        LOGGER.warning("URL Error [Errno %d] %s" % (e.errno, e.strerror))
+        LOGGER.warning("Connection Error: %s" % (e))
     return {}
